@@ -3,6 +3,7 @@ import warnings
 from contextlib import contextmanager
 from functools import singledispatch
 from textwrap import dedent
+from typing import Union
 
 import numba
 import numba.np.unsafe.ndarray as numba_ndarray
@@ -96,11 +97,13 @@ def get_numba_type(
 
 
 def create_numba_signature(
-    node: Apply, force_scalar: bool = False, reduce_to_scalar: bool = False
+    node_or_fgraph: Union[FunctionGraph, Apply],
+    force_scalar: bool = False,
+    reduce_to_scalar: bool = False,
 ) -> numba.types.Type:
-    """Create a Numba type for the signature of an ``Apply`` node."""
+    """Create a Numba type for the signature of an `Apply` node or `FunctionGraph`."""
     input_types = []
-    for inp in node.inputs:
+    for inp in node_or_fgraph.inputs:
         input_types.append(
             get_numba_type(
                 inp.type, force_scalar=force_scalar, reduce_to_scalar=reduce_to_scalar
@@ -108,7 +111,7 @@ def create_numba_signature(
         )
 
     output_types = []
-    for out in node.outputs:
+    for out in node_or_fgraph.outputs:
         output_types.append(
             get_numba_type(
                 out.type, force_scalar=force_scalar, reduce_to_scalar=reduce_to_scalar
@@ -390,10 +393,14 @@ def numba_funcify_FunctionGraph(
 def create_index_func(node, objmode=False):
     """Create a Python function that assembles and uses an index on an array."""
 
+    unique_names = unique_name_generator(
+        ["subtensor", "incsubtensor", "z"], suffix_sep="_"
+    )
+
     def convert_indices(indices, entry):
         if indices and isinstance(entry, Type):
             rval = indices.pop(0)
-            return rval.auto_name
+            return unique_names(rval)
         elif isinstance(entry, slice):
             return (
                 f"slice({convert_indices(indices, entry.start)}, "
@@ -410,10 +417,6 @@ def create_index_func(node, objmode=False):
     )
     index_start_idx = 1 + int(set_or_inc)
 
-    unique_names = unique_name_generator(
-        ["subtensor", "incsubtensor", "z"], suffix_sep="_"
-    )
-
     input_names = [unique_names(v, force_unique=True) for v in node.inputs]
     op_indices = list(node.inputs[index_start_idx:])
     idx_list = getattr(node.op, "idx_list", None)
