@@ -8,7 +8,7 @@ from collections import Counter, defaultdict
 from keyword import iskeyword
 from operator import itemgetter
 from tempfile import NamedTemporaryFile
-from textwrap import indent
+from textwrap import dedent, indent
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -243,7 +243,7 @@ def gc_helper(node_list: List[Apply]):
     -------
     2-tuple
         FIRST, the set of Variable instances which are computed by node_list,
-        and SECOND a dictionary that maps each Variable instance to a the last
+        and SECOND a dictionary that maps each Variable instance to the last
         node to use Variable as an input.
 
     Extended Summary
@@ -613,8 +613,8 @@ def compile_function_src(
 def get_name_for_object(x: Any) -> str:
     """Get the name for an arbitrary object."""
 
-    if isinstance(x, Variable):
-        name = re.sub("[^0-9a-zA-Z]+", "_", x.name) if x.name else ""
+    if isinstance(x, Variable) and x.name:
+        name = re.sub("[^0-9a-zA-Z]+", "_", x.name)
         name = (
             name
             if (
@@ -622,19 +622,22 @@ def get_name_for_object(x: Any) -> str:
                 and not iskeyword(name)
                 and name not in dir(builtins)
             )
-            else x.auto_name
+            else ""
         )
     else:
-        name = getattr(x, "__name__", "")
+        name = re.sub(r"(?<!^)(?=[A-Z])", "_", getattr(x, "__name__", "")).lower()
 
     if not name or (not name.isidentifier() or iskeyword(name)):
-        name = type(x).__name__
+        # Try to get snake-case out of the type name
+        name = re.sub(r"(?<!^)(?=[A-Z])", "_", type(x).__name__).lower()
+
+    assert name.isidentifier() and not iskeyword(name)
 
     return name
 
 
 def unique_name_generator(
-    external_names: Optional[List[str]] = None, suffix_sep: str = ""
+    external_names: Optional[List[str]] = None, suffix_sep: str = "_"
 ) -> Callable:
     """Create a function that generates unique names."""
 
@@ -764,6 +767,19 @@ def fgraph_to_python(
         assign_str = f"{', '.join(node_output_names)} = {local_compiled_func_name}({', '.join(node_input_names)})"
         body_assigns.append(f"{assign_comment_str}\n{assign_str}")
 
+    # Handle `Constant`-only outputs (these don't have associated `Apply`
+    # nodes, so the above isn't applicable)
+    for out in fgraph.outputs:
+        if isinstance(out, Constant):
+            local_input_name = unique_name(out)
+            if local_input_name not in global_env:
+                global_env[local_input_name] = type_conversion_fn(
+                    storage_map[out][0],
+                    variable=out,
+                    storage=storage_map[out],
+                    **kwargs,
+                )
+
     fgraph_input_names = [unique_name(v) for v in fgraph.inputs]
     fgraph_output_names = [unique_name(v) for v in fgraph.outputs]
     joined_body_assigns = indent("\n".join(body_assigns), "    ")
@@ -775,11 +791,13 @@ def fgraph_to_python(
     else:
         fgraph_return_src = ", ".join(fgraph_output_names)
 
-    fgraph_def_src = f"""
-def {fgraph_name}({", ".join(fgraph_input_names)}):
-{joined_body_assigns}
-    return {fgraph_return_src}
+    fgraph_def_src = dedent(
+        f"""
+    def {fgraph_name}({", ".join(fgraph_input_names)}):
+    {indent(joined_body_assigns, " " * 4)}
+        return {fgraph_return_src}
     """
+    ).strip()
 
     if local_env is None:
         local_env = locals()
