@@ -15,12 +15,6 @@ class SparseTensorSharedVariable(_sparse_py_operators, SharedVariable):
 def sparse_constructor(
     value, name=None, strict=False, allow_downcast=None, borrow=False, format=None
 ):
-    """
-    SharedVariable Constructor for SparseTensorType.
-
-    writeme
-
-    """
     if not isinstance(value, scipy.sparse.spmatrix):
         raise TypeError(
             "Expected a sparse matrix in the sparse shared variable constructor. Received: ",
