@@ -761,6 +761,18 @@ def safe_multivariate_normal(mean, cov, size=None, rng=None):
 
 
 class MvNormalRV(RandomVariable):
+    r"""A multivariate normal random variable.
+
+    The probability density function for `multivariate_normal` in term of its location parameter
+    :math:`\boldsymbol{\mu}` and covariance matrix :math:`\Sigma` is
+
+    .. math::
+
+        f(\boldsymbol{x}; \boldsymbol{\mu}, \Sigma) = \det(2 \pi \Sigma)^{-1/2}  \exp\left(-\frac{1}{2} (\boldsymbol{x} - \boldsymbol{\mu})^T \Sigma (\boldsymbol{x} - \boldsymbol{\mu})\right)
+
+    where :math:`\Sigma` is a positive semi-definite matrix.
+
+    """
     name = "multivariate_normal"
     ndim_supp = 1
     ndims_params = [1, 2]
@@ -768,7 +780,23 @@ class MvNormalRV(RandomVariable):
     _print_name = ("N", "\\operatorname{N}")
 
     def __call__(self, mean=None, cov=None, size=None, **kwargs):
+        r""" "Draw samples from a multivariate normal distribution.
 
+        Parameters
+        ----------
+        mean
+            Location parameter (mean) :math:`\boldsymbol{\mu}` of the distribution. Vector
+            of length `N`.
+        cov
+            Covariance matrix :math:`\Sigma` of the distribution. Must be a symmetric
+            and positive-semidefinite `NxN` matrix.
+        size
+            Given a size of, for example, `(m, n, k)`, `m * n * k` independent,
+            identically distributed samples are generated. Because each sample
+            is `N`-dimensional, the output shape is `(m, n, k, N)`. If no shape
+            is specified, a single `N`-dimensional sample is returned.
+
+        """
         dtype = aesara.config.floatX if self.dtype == "floatX" else self.dtype
 
         if mean is None:
@@ -834,10 +862,10 @@ class DirichletRV(RandomVariable):
             A sequence of concentration parameters :math:`\boldsymbol{\alpha}` of the
             distribution. A sequence of length `k` will produce samples of length `k`.
         size
-            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
-            independent, identically distributed random variables are
-            returned. Default is `None` in which case a vector of length `k`
-            is returned.
+            Given a size of, for example, `(r, s, t)`, `r * s * t` independent,
+            identically distributed samples are generated. Because each sample
+            is `k`-dimensional, the output shape is `(r, s, t, k)`. If no shape
+            is specified, a single `k`-dimensional sample is returned.
 
         """
         return super().__call__(alphas, size=size, **kwargs)
@@ -931,13 +959,11 @@ class GeometricRV(RandomVariable):
         Parameters
         ----------
         p
-           Probability of success :math:`p` of an individual trial.
+            Probability of success :math:`p` of an individual trial.
         size
-           Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
-           independent, identically distributed random variables are
-           returned. Default is `None` in which case a single random variable
-           is returned if `p` is a scalar. Otherwise `np.array(p).size` samples
-           are drawn.
+            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n *
+            k` independent, identically distributed samples are returned.
+            Default is `None` in which case a single sample is returned.
 
         """
         return super().__call__(p, size=size, **kwargs)
@@ -970,18 +996,16 @@ class HyperGeometricRV(RandomVariable):
         Parameters
         ----------
         ngood
-            Number :math:`K` of desirable items in the population.
+            Number :math:`K` of desirable items in the population. Positive integer.
         nbad
-            Number :math:`N-K` of undesirable items in the population.
+            Number :math:`N-K` of undesirable items in the population. Positive integer.
         nsample
             Number :math:`n` of items sampled. Must be less than :math:`N`,
-            i.e. `ngood + nbad`.`
+            i.e. `ngood + nbad`.` Positive integer.
         size
            Sample shape. If the given size is, e.g. `(m, n, k)` then `m * n * k`
-           independent, identically distributed random variables are
-           returned. Default is `None` in which case a single random variable
-           is returned if `ngood`, `nbad` and `nsample` are all scalars.
-           Otherwise `np.broadcast(ngood, nbad, nsample).size` samples are drawn.
+           independent, identically distributed samples are returned. Default is
+           `None` in which case a single sample is returned.
 
         """
         return super().__call__(ngood, nbad, nsample, size=size, **kwargs)
@@ -991,6 +1015,18 @@ hypergeometric = HyperGeometricRV()
 
 
 class CauchyRV(ScipyRandomVariable):
+    r"""A Cauchy continuous random variable.
+
+    The probability density function for `cauchy` in terms of its location
+    parameter :math:`x_0` and scale parameter :math:`\gamma` is:
+
+    .. math::
+
+        f(x; x_0, \gamma) = \frac{1}{\pi \gamma \left(1 + (\frac{x-x_0}{\gamma})^2\right)}
+
+    where :math:`\gamma > 0`.
+
+    """
     name = "cauchy"
     ndim_supp = 0
     ndims_params = [0, 0]
@@ -998,6 +1034,21 @@ class CauchyRV(ScipyRandomVariable):
     _print_name = ("C", "\\operatorname{C}")
 
     def __call__(self, loc=0.0, scale=1.0, size=None, **kwargs):
+        r"""Draw samples from a Cauchy distribution.
+
+        Parameters
+        ----------
+        loc
+            Location parameter :math:`x_0` of the distribution.
+        scale
+            Scale parameter :math:`\gamma` of the distribution. Must be
+            positive.
+        size
+           Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+           independent, identically distributed samples are returned. Default is
+           `None` in which case a single sample is returned.
+
+        """
         return super().__call__(loc, scale, size=size, **kwargs)
 
     @classmethod
@@ -1009,6 +1060,18 @@ cauchy = CauchyRV()
 
 
 class HalfCauchyRV(ScipyRandomVariable):
+    r"""A half-Cauchy continuous random variable.
+
+    The probability density function for `halfcauchy` in terms of its location
+    parameter :math:`x_0` and scale parameter :math:`\gamma` is:
+
+    .. math::
+
+        f(x; x_0, \gamma) = \frac{1}{\pi \gamma \left(1 + (\frac{x-x_0}{\gamma})^2\right)}
+
+    for :math:`x \geq 0` where :math:`\gamma > 0`.
+
+    """
     name = "halfcauchy"
     ndim_supp = 0
     ndims_params = [0, 0]
@@ -1016,6 +1079,21 @@ class HalfCauchyRV(ScipyRandomVariable):
     _print_name = ("C**+", "\\operatorname{C^{+}}")
 
     def __call__(self, loc=0.0, scale=1.0, size=None, **kwargs):
+        r"""Draw samples from a half-Cauchy distribution.
+
+        Parameters
+        ----------
+        loc
+            Location parameter :math:`x_0` of the distribution.
+        scale
+            Scale parameter :math:`\gamma` of the distribution. Must be
+            positive.
+        size
+           Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+           independent, identically distributed samples are returned. Default is
+           `None`, in which case a single sample is returned.
+
+        """
         return super().__call__(loc, scale, size=size, **kwargs)
 
     @classmethod
@@ -1027,21 +1105,67 @@ halfcauchy = HalfCauchyRV()
 
 
 class InvGammaRV(ScipyRandomVariable):
+    r"""An inverse-gamma continuous random variable.
+
+    The probability density function for `invgamma` in terms of its shape
+    parameter :math:`\alpha` and scale parameter :math:`\beta` is:
+
+    .. math::
+
+        f(x; \alpha, \beta) = \frac{\beta^\alpha}{\Gamma(\alpha)} x^{-(\alpha+1)} \exp\left(-\frac{\beta}{x}\right)
+
+    for :math:`x > 0`, where :math:`\alpha > 0` and :math:`\beta > 0`. :math:`Gamma` is the gamma function :
+
+    .. math::
+
+        \Gamma(x) = \int_0^{\infty} t^{x-1} e^{-t} \mathrm{d}t
+
+    """
     name = "invgamma"
     ndim_supp = 0
     ndims_params = [0, 0]
     dtype = "floatX"
     _print_name = ("InvGamma", "\\operatorname{Gamma^{-1}}")
 
+    def __call__(self, shape, scale, size=None, **kwargs):
+        r"""Draw samples from an inverse-gamma distribution.
+
+        Parameters
+        ----------
+        shape
+            Shape parameter :math:`\alpha` of the distribution. Must be positive.
+        scale
+            Scale parameter :math:`\beta` of the distribution. Must be
+            positive.
+        size
+           Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+           independent, identically distributed sample are returned. Default is
+           `None`, in which case a single sample is returned.
+
+        """
+        return super().__call__(shape, scale, size=size, **kwargs)
+
     @classmethod
-    def rng_fn_scipy(cls, rng, shape, rate, size):
-        return stats.invgamma.rvs(shape, scale=rate, size=size, random_state=rng)
+    def rng_fn_scipy(cls, rng, shape, scale, size):
+        return stats.invgamma.rvs(shape, scale=scale, size=size, random_state=rng)
 
 
 invgamma = InvGammaRV()
 
 
 class WaldRV(RandomVariable):
+    r"""A Wald (or inverse Gaussian) continuous random variable.
+
+    The probability density function for `wald` in terms of its mean
+    parameter :math:`\mu` and shape parameter :math:`\lambda` is:
+
+    .. math::
+
+        f(x; \mu, \lambda) = \sqrt{\frac{\lambda}{2 \pi x^3}} \exp\left(-\frac{\lambda (x-\mu)^2}{2 \mu^2 x}\right)
+
+    for :math:`x > 0`, where :math:`\mu > 0` and :math:`\lambda > 0`.
+
+    """
     name = "wald"
     ndim_supp = 0
     ndims_params = [0, 0]
@@ -1049,6 +1173,21 @@ class WaldRV(RandomVariable):
     _print_name_ = ("Wald", "\\operatorname{Wald}")
 
     def __call__(self, mean=1.0, scale=1.0, size=None, **kwargs):
+        r"""Draw samples from a Wald distribution.
+
+        Parameters
+        ----------
+        mean
+            Mean parameter :math:`\mu` of the distribution. Must be positive.
+        shape
+            Shape parameter :math:`\lambda` of the distribution. Must be
+            positive.
+        size
+           Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+           independent, identically distributed samples are returned. Default is
+           `None`, in which case a single sample is returned.
+
+        """
         return super().__call__(mean, scale, size=size, **kwargs)
 
 
@@ -1056,12 +1195,45 @@ wald = WaldRV()
 
 
 class TruncExponentialRV(ScipyRandomVariable):
+    r"""A truncated exponential continuous random variable.
+
+    The probability density function for `truncexp` in terms of its shape
+    parameter :math:`b`, location parameter :math:`\alpha` and scale
+    parameter :math:`\beta` is:
+
+    .. math::
+
+        f(x; b, \alpha, \beta) = \frac{\exp(-(x-\alpha)/\beta)}{\beta (1-\exp(-b))}
+
+    for :math:`0 \leq x \leq b` and :math:`\beta > 0`.
+
+    """
     name = "truncexpon"
     ndim_supp = 0
     ndims_params = [0, 0, 0]
     dtype = "floatX"
     _print_name = ("TruncExp", "\\operatorname{TruncExp}")
 
+    def __call__(self, b, loc=0.0, scale=1.0, size=None, **kwargs):
+        r"""Draw samples from a truncated exponential distribution.
+
+        Parameters
+        ----------
+        b
+            Shape parameter :math:`b` of the distribution. Must be positive.
+        loc
+            Location parameter :math:`\alpha` of the distribution.
+        scale
+            Scale parameter :math:`\beta` of the distribution. Must be
+            positive.
+        size
+           Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+           independent, identically distributed samples are returned. Default is
+           `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(b, loc, scale, size=size, **kwargs)
+
     @classmethod
     def rng_fn_scipy(cls, rng, b, loc, scale, size):
         return stats.truncexpon.rvs(
@@ -1073,12 +1245,45 @@ truncexpon = TruncExponentialRV()
 
 
 class BernoulliRV(ScipyRandomVariable):
+    r"""A Bernoulli discrete random variable.
+
+    The probability mass function for `bernoulli` in terms of the probability
+    of success :math:`p` of a single trial is:
+
+
+    .. math::
+
+        \begin{split}
+            f(k; p) = \begin{cases}
+                                (1-p)\quad \text{if $k = 0$},\\
+                                p\quad \text{if $k=1$}\\
+                        \end{cases}
+        \end{split}
+
+    where :math:`0 \leq p \leq 1`.
+
+    """
     name = "bernoulli"
     ndim_supp = 0
     ndims_params = [0]
     dtype = "int64"
     _print_name = ("Bern", "\\operatorname{Bern}")
 
+    def __call__(self, p, size=None, **kwargs):
+        r"""Draw samples from a Bernoulli distribution.
+
+        Parameters
+        ----------
+        p
+            Probability of success :math:`p` of a single trial.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are returned. Default
+            is `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(p, size=size, **kwargs)
+
     @classmethod
     def rng_fn_scipy(cls, rng, p, size):
         return stats.bernoulli.rvs(p, size=size, random_state=rng)
@@ -1088,34 +1293,120 @@ bernoulli = BernoulliRV()
 
 
 class LaplaceRV(RandomVariable):
+    r"""A Laplace continuous random variable.
+
+    The probability density function for `laplace` in terms of its location
+    parameter :math:`\mu` and scale parameter :math:`\lambda` is:
+
+    .. math::
+
+        f(x; \mu, \lambda) = \frac{1}{2 \lambda} \exp\left(-\frac{|x-\mu|}{\lambda}\right)
+
+    with :math:`\lambda > 0`.
+
+    """
     name = "laplace"
     ndim_supp = 0
     ndims_params = [0, 0]
     dtype = "floatX"
     _print_name = ("Laplace", "\\operatorname{Laplace}")
 
+    def __call__(self, loc=0.0, scale=1.0, size=None, **kwargs):
+        r"""Draw samples from a Laplace distribution.
+
+        Parameters
+        ----------
+        loc
+            Location parameter :math:`\mu` of the distribution.
+        scale
+            Scale parameter :math:`\lambda` of the distribution. Must be
+            positive.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are returned. Default
+            is `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(loc, scale, size=size, **kwargs)
+
 
 laplace = LaplaceRV()
 
 
 class BinomialRV(RandomVariable):
+    r"""A binomial discrete random variable.
+
+    The probability mass function for `binomial` for the number :math:`k` of successes
+    in terms of the probability of success :math:`p` of a single trial and the number
+    :math:`n` of trials is:
+
+    .. math::
+
+            f(k; p, n) = {n \choose k} p^k (1-p)^{n-k}
+
+    """
     name = "binomial"
     ndim_supp = 0
     ndims_params = [0, 0]
     dtype = "int64"
     _print_name = ("Binom", "\\operatorname{Binom}")
 
+    def __call__(self, n, p, size=None, **kwargs):
+        r"""Draw samples from a binomial distribution.
+
+        Parameters
+        ----------
+        n
+            Number of trials :math:`n`. Must be a positive integer.
+        p
+            Probability of success :math:`p` of a single trial.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are returned. Default
+            is `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(n, p, size=size, **kwargs)
+
 
 binomial = BinomialRV()
 
 
 class NegBinomialRV(ScipyRandomVariable):
+    r"""A negative binomial discrete random variable.
+
+    The probability mass function for `nbinom` for the number :math:`k` of draws
+    before observing the :math:`n`\th success in terms of the probability of
+    success :math:`p` of a single trial is:
+
+    .. math::
+
+            f(k; p, n) = {k+n-1 \choose n-1} p^n (1-p)^{k}
+
+    """
     name = "nbinom"
     ndim_supp = 0
     ndims_params = [0, 0]
     dtype = "int64"
     _print_name = ("NB", "\\operatorname{NB}")
 
+    def __call__(self, n, p, size=None, **kwargs):
+        r"""Draw samples from a negative binomial distribution.
+
+        Parameters
+        ----------
+        n
+            Number of successes :math:`n`. Must be a positive integer.
+        p
+            Probability of success :math:`p` of a single trial.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are returned. Default
+            is `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(n, p, size=size, **kwargs)
+
     @classmethod
     def rng_fn_scipy(cls, rng, n, p, size):
         return stats.nbinom.rvs(n, p, size=size, random_state=rng)
@@ -1126,12 +1417,48 @@ negative_binomial = NegBinomialRV()
 
 
 class BetaBinomialRV(ScipyRandomVariable):
+    r"""A beta-binomial discrete random variable.
+
+    The probability mass function for `betabinom` in terms of its shape
+    parameters :math:`n \geq 0`, :math:`a > 0`, :math:`b > 0` and the probability
+    :math:`p` is:
+
+    .. math::
+
+            f(k; p, n, a, b) = {n \choose k} \frac{\operatorname{B}(k+a, n-k+b)}{\operatorname{B}(a,b)}
+
+    where :math:`\operatorname{B}` is the beta function:
+
+    .. math::
+
+        \operatorname{B}(a, b) = \int_0^1 t^{a-1} (1-t)^{b-1} \mathrm{d}t
+
+    """
     name = "beta_binomial"
     ndim_supp = 0
     ndims_params = [0, 0, 0]
     dtype = "int64"
     _print_name = ("BetaBinom", "\\operatorname{BetaBinom}")
 
+    def __call__(self, n, a, b, size=None, **kwargs):
+        r"""Draw samples from a beta-binomial distribution.
+
+        Parameters
+        ----------
+        n
+            Shape parameter :math:`n`. Must be a positive integer.
+        a
+            Shape parameter :math:`a`. Must be positive.
+        b
+            Shape parameter :math:`b`. Must be positive.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are returned. Default
+            is `None` in which case a single sample is returned.
+
+        """
+        return super().__call__(n, a, b, size=size, **kwargs)
+
     @classmethod
     def rng_fn_scipy(cls, rng, n, a, b, size):
         return stats.betabinom.rvs(n, a, b, size=size, random_state=rng)
@@ -1141,6 +1468,18 @@ betabinom = BetaBinomialRV()
 
 
 class GenGammaRV(ScipyRandomVariable):
+    r"""A generalized gamma continuous random variable.
+
+    The probability density function of `gengamma` in terms of its scale parameter
+    :math:`\alpha` and other parameters :math:`p` and :math:`\lambda` is:
+
+    .. math::
+
+            f(x; \alpha, \lambda, p) = \frac{p/\lambda^\alpha}{\Gamma(\alpha/p)} x^{\alpha-1} e^{-(x/\lambda)^p}
+
+    for :math:`x > 0`, where :math:`\alpha, \lambda, p > 0`.
+
+    """
     name = "gengamma"
     ndim_supp = 0
     ndims_params = [0, 0, 0]
@@ -1148,6 +1487,23 @@ class GenGammaRV(ScipyRandomVariable):
     _print_name = ("GG", "\\operatorname{GG}")
 
     def __call__(self, alpha=1.0, p=1.0, lambd=1.0, size=None, **kwargs):
+        r"""Draw samples from a generalized gamma distribution.
+
+        Parameters
+        ----------
+        alpha
+            Parameter :math:`\alpha`. Must be positive.
+        p
+            Parameter :math:`p`. Must be positive.
+        lambd
+            Scale parameter :math:`\lambda`. Must be positive.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are
+            returned. Default is `None` in which case a single sample
+            is returned.
+
+        """
         return super().__call__(alpha, p, lambd, size=size, **kwargs)
 
     @classmethod
@@ -1161,20 +1517,50 @@ gengamma = GenGammaRV()
 
 
 class MultinomialRV(RandomVariable):
-    """A Multinomial random variable type.
+    r"""A multinomial discrete random variable.
+
+    The probability mass function of `multinomial` in terms of the number
+    of experiments :math:`n` and the probabilities :math:`p_1, \dots, p_k`
+    of the :math:`k` different possible outcomes is:
+
+
+    .. math::
+
+        f(x_1,\dots,x_k; n, p_1, \dots, p_k) = \frac{n!}{x_1! \dots x_k!} \prod_{i=1}^k x_i^{p_i}
+
+
+    where :math:`n>0` and :math:`\sum_{i=1}^k p_i = 1`.
 
     Notes
     -----
     The length of the support dimension is determined by the last
     dimension in the *second* parameter (i.e.  the probabilities vector).
-    """
 
+    """
     name = "multinomial"
     ndim_supp = 1
     ndims_params = [0, 1]
     dtype = "int64"
     _print_name = ("MN", "\\operatorname{MN}")
 
+    def __call__(self, n, p, size=None, **kwargs):
+        r"""Draw samples from a discrete multinomial distribution.
+
+        Parameters
+        ----------
+        n
+            Number of experiments :math:`n`. Must be a positive integer.
+        p
+            Probabilities of each of the :math:`k` different outcomes.
+        size
+            Given a size of, for example, `(r, s, t)`, `r * s * t` independent,
+            identically distributed samples are generated. Because each sample
+            is `k`-dimensional, the output shape is `(r, s, t, k)`. If no shape
+            is specified, a single `k`-dimensional sample is returned.
+
+        """
+        return super().__call__(n, p, size=size, **kwargs)
+
     def _supp_shape_from_params(self, dist_params, rep_param_idx=1, param_shapes=None):
         return default_supp_shape_from_params(
             self.ndim_supp, dist_params, rep_param_idx, param_shapes
@@ -1205,12 +1591,41 @@ vsearchsorted = np.vectorize(np.searchsorted, otypes=[int], signature="(n),()->(
 
 
 class CategoricalRV(RandomVariable):
+    r"""A categorical discrete random variable.
+
+    The probability mass function of `categorical` in terms of its :math:`N` event
+    probabilities :math:`p_1, \dots, p_N` is:
+
+    .. math::
+
+        P(k=i) = p_k
+
+    where :math:`\sum_i p_i = 1`.
+
+    """
+
     name = "categorical"
     ndim_supp = 0
     ndims_params = [1]
     dtype = "int64"
     _print_name = ("Cat", "\\operatorname{Cat}")
 
+    def __call__(self, p, size=None, **kwargs):
+        r"""Draw samples from a discrete categorical distribution.
+
+        Parameters
+        ----------
+        p
+            An array that contains the :math:`N` event probabilities.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed random samples are
+            returned. Default is `None`, in which case a single sample
+            is returned.
+
+        """
+        return super().__call__(p, size=size, **kwargs)
+
     @classmethod
     def rng_fn(cls, rng, p, size):
         if size is None:
@@ -1234,6 +1649,12 @@ categorical = CategoricalRV()
 
 
 class RandIntRV(RandomVariable):
+    r"""A discrete uniform random variable.
+
+    Only available for `RandomStateType`. Use `integers` with `RandomGeneratorType`\s.
+
+    """
+
     name = "randint"
     ndim_supp = 0
     ndims_params = [0, 0]
@@ -1241,6 +1662,25 @@ class RandIntRV(RandomVariable):
     _print_name = ("randint", "\\operatorname{randint}")
 
     def __call__(self, low, high=None, size=None, **kwargs):
+        r"""Draw samples from a discrete uniform distribution.
+
+        Parameters
+        ----------
+        low
+            Lower boundary of the output interval. All values generated will
+            be greater than or equal to `low`, unless `high=None`, in which case
+            all values generated are greater than or equal to `0` and
+            smaller than `low` (exclusive).
+        high
+            Upper boundary of the output interval.  All values generated
+            will be smaller than `high` (exclusive).
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are
+            returned. Default is `None`, in which case a single
+            sample is returned.
+
+        """
         if high is None:
             low, high = 0, low
         return super().__call__(low, high, size=size, **kwargs)
@@ -1257,6 +1697,11 @@ randint = RandIntRV()
 
 
 class IntegersRV(RandomVariable):
+    r"""A discrete uniform random variable.
+
+    Only available for `RandomGeneratorType`. Use `randint` with `RandomStateType`\s.
+
+    """
     name = "integers"
     ndim_supp = 0
     ndims_params = [0, 0]
@@ -1264,6 +1709,23 @@ class IntegersRV(RandomVariable):
     _print_name = ("integers", "\\operatorname{integers}")
 
     def __call__(self, low, high=None, size=None, **kwargs):
+        r"""Draw samples from a discrete uniform distribution.
+
+        Parameters
+        ----------
+        low
+            Lower boundary of the output interval.  All values generated
+            will be greater than or equal to `low` (inclusive).
+        high
+            Upper boundary of the output interval.  All values generated
+            will be smaller than `high` (exclusive).
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n * k`
+            independent, identically distributed samples are
+            returned. Default is `None`, in which case a single sample
+            is returned.
+
+        """
         if high is None:
             low, high = 0, low
         return super().__call__(low, high, size=size, **kwargs)
@@ -1281,6 +1743,8 @@ integers = IntegersRV()
 
 
 class ChoiceRV(RandomVariable):
+    """Randomly choose an element in a sequence."""
+
     name = "choice"
     ndim_supp = 0
     ndims_params = [1, 1, 0]
@@ -1295,14 +1759,40 @@ class ChoiceRV(RandomVariable):
         raise NotImplementedError()
 
     def _infer_shape(self, size, dist_params, param_shapes=None):
-        return size
+        (a, p, _) = dist_params
+
+        if isinstance(p.type, aesara.tensor.type_other.NoneTypeT):
+            shape = super()._infer_shape(size, (a,), param_shapes)
+        else:
+            shape = super()._infer_shape(size, (a, p), param_shapes)
+
+        return shape
 
     def __call__(self, a, size=None, replace=True, p=None, **kwargs):
+        r"""Generate a random sample from an array.
 
-        a = as_tensor_variable(a, ndim=1)
+        Parameters
+        ----------
+        a
+            The array from which to randomly sample an element. If an int,
+            a sample is generated from `aesara.tensor.arange(a)`.
+        size
+            Sample shape. If the given size is `(m, n, k)`, then `m * n *
+            k` independent samples are returned. Default is `None`, in
+            which case a single sample is returned.
+        replace
+            When ``True``, sampling is performed with replacement.
+        p
+            The probabilities associated with each entry in `a`. If not
+            given, all elements have equal probability.
+        """
+        a = as_tensor_variable(a)
+
+        if a.ndim == 0:
+            a = aesara.tensor.arange(a)
 
         if p is None:
-            p = aesara.tensor.type_other.NoneConst.clone()
+            p = aesara.tensor.type_other.NoneConst
 
         if isinstance(replace, bool):
             replace = aesara.tensor.constant(np.array(replace))
@@ -1314,6 +1804,8 @@ choice = ChoiceRV()
 
 
 class PermutationRV(RandomVariable):
+    """Randomly shuffle a sequence."""
+
     name = "permutation"
     ndim_supp = 1
     ndims_params = [1]
@@ -1337,6 +1829,15 @@ class PermutationRV(RandomVariable):
             return x_shape
 
     def __call__(self, x, **kwargs):
+        r"""Randomly permute a sequence or a range of values.
+
+        Parameters
+        ----------
+        x
+            If `x` is an integer, randomly permute `np.arange(x)`. If `x` is a sequence,
+            shuffle its elements randomly.
+
+        """
         x = as_tensor_variable(x)
         return super().__call__(x, dtype=x.dtype, **kwargs)
 
